componenttools.all_are_components_scalable_by_multiplier
========================================================

.. autofunction:: abjad.tools.componenttools.all_are_components_scalable_by_multiplier.all_are_components_scalable_by_multiplier
